==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGridTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebGridTemplateContextDescription } from "./WebGridTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridTemplateContextDescriptionMetadata.a == null) {
                WebGridTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridTemplateContextDescriptionMetadata.c(WebGridTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridTemplateContextDescriptionMetadata.a);
            WebGridBaseDirectiveDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebGridBaseDirective");
        }
        static d(a) {
            WebGridTemplateContextDescriptionMetadata.b(a);
            a.ad("WebGridTemplateContext", () => new WebGridTemplateContextDescription());
            a.ac("WebGridTemplateContext", WebGridTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridTemplateContextDescriptionMetadata, 'WebGridTemplateContextDescriptionMetadata');
    WebGridTemplateContextDescriptionMetadata.a = null;
    return WebGridTemplateContextDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebGridTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebGridTemplateContextDescription } from "./WebGridTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridTemplateContextDescriptionMetadata.a == null) {
                WebGridTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridTemplateContextDescriptionMetadata.c(WebGridTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridTemplateContextDescriptionMetadata.a);
            WebGridBaseDirectiveDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebGridBaseDirective");
        }
        static d(a) {
            WebGridTemplateContextDescriptionMetadata.b(a);
            a.ae("WebGridTemplateContext", () => new WebGridTemplateContextDescription());
            a.ad("WebGridTemplateContext", WebGridTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridTemplateContextDescriptionMetadata, 'WebGridTemplateContextDescriptionMetadata');
    WebGridTemplateContextDescriptionMetadata.a = null;
    return WebGridTemplateContextDescriptionMetadata;
})();
